"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@babel/core");
function isReactFragment(node) {
    return (node.name.name === 'Fragment' ||
        (node.name.type === 'JSXMemberExpression' &&
            node.name.object.name === 'React' &&
            node.name.property.name === 'Fragment'));
}
function isClassNameAlreadySet(node, className) {
    if (!node.attributes)
        return false;
    const classNameAttrIndex = node.attributes &&
        node.attributes.findIndex((attr) => attr.name && attr.name.name === 'className');
    if (classNameAttrIndex !== -1) {
        return (node.attributes[classNameAttrIndex].value &&
            node.attributes[classNameAttrIndex].value.value &&
            node.attributes[classNameAttrIndex].value.value
                .split(' ')
                .includes(className));
    }
    return false;
}
function applyClassName({ openingElement, className }) {
    if (!openingElement || !className)
        return;
    const apply = (node) => {
        const pushOrReplaceClassName = (node, className) => {
            const classNameAttrIndex = node.attributes.findIndex((attr) => attr.name && attr.name.name === 'className');
            if (node.attributes.length === 0 || classNameAttrIndex === -1) {
                node.attributes.push(core_1.types.jsxAttribute(core_1.types.jsxIdentifier('className'), core_1.types.stringLiteral(className)));
            }
            else {
                node.attributes[classNameAttrIndex].value = core_1.types.stringLiteral(`${node.attributes[classNameAttrIndex].value.value} ${className}`);
            }
        };
        if (!isReactFragment(node) && !isClassNameAlreadySet(node, className)) {
            if (Array.isArray(className)) {
                className.forEach(c => {
                    pushOrReplaceClassName(node, c);
                });
            }
            else {
                pushOrReplaceClassName(node, className);
            }
        }
    };
    apply(openingElement);
}
function default_1({}) {
    const visitor = {
        JSXOpeningElement(path, { opts }) {
            if (!path.node.name)
                return;
            const customClassName = opts.className;
            applyClassName({
                openingElement: path.node,
                className: customClassName,
            });
        },
    };
    return {
        name: 'add-jsx-classes',
        visitor,
    };
}
exports.default = default_1;
